@@ -42,6 +42,7 @@
 #include "options.h"
 #include "themes.h"
 #include "event.h"
+#include "delay.h"
 
 // fix -- make this not need to be a global
 Line line1;
@@ -115,6 +116,7 @@ LevelExitType playlevel(int level, long oldscore, ScoreSheet * levelscore)
 	int keyboardcounter=0;
 	int keyboarddelay=0;
 	
+	Uint32 loopstartticks;
 	
 	int done = false;
 	
@@ -185,6 +187,8 @@ LevelExitType playlevel(int level, long oldscore, ScoreSheet * levelscore)
 	
 	do 
 	{
+		loopstartticks = SDL_GetTicks();
+	
 		// FIX -- this is way too messy. time to split it up into
 		// neat little functions or something. Especially the menubutton stuff.
 		while (pollevent(&event))
@@ -619,15 +623,11 @@ LevelExitType playlevel(int level, long oldscore, ScoreSheet * levelscore)
 
 		//printboard();
 		
-		// oh, if only we could sleep for less than 10ms on 
-		// intel. too bad alpha systems suck so much in other
-		// ways -- they can sleep with 1ms resolution.
-		// (we could on intel with nanosleep, if we were suid root...)
-		SDL_Delay(10);
+		delaytil(loopstartticks+MSECPERFRAME);
+
 		
 	} while (!done);
 
-
 	// make sure visible penguins are actually in the screen memory,
 	// and then erase them so we don't leak surfaces.
 	for (i=0;i<penguincount;i++)
