@@ -586,7 +586,7 @@ PopupReturnType menuhandler(SDL_Rect menurect, int menulength, char ** menuitems
 	PopupReturnType rc=POPUPDONOTHING;
 	int redrawmenuflag=false;
 	int domenuitemflag=false;
-	Uint8 domenuitembutton;
+	Uint8 domenuitembutton=0;
 
 	int i;
 
