@@ -63,6 +63,14 @@ int snprintf_mingw32kludge(char *str, size_t size, const char *fmt, ...)
 	return rc;
 }
 
+int vsnprintf_mingw32kludge(char *str, size_t size, const  char  *fmt, va_list ap)
+{
+	int rc;
+	rc=_vsnprintf(str,size-1,fmt,ap);
+	*(str+size-1)='\0';
+	return rc;
+}
+
 
 struct passwd *getpwuid(int id)
 {
