@@ -37,12 +37,16 @@
 
 #ifdef __MINGW32__
 
+#include <stdarg.h>
+
 /* mingw32 is missing snprintf. It has  _snprintf, 
    but unfortunately and stupidly, the size parameter has an off-by-one
    error causing it to write one more char than requested. this is a
    workaround.... */
 #define snprintf snprintf_mingw32kludge
+#define vsnprintf vsnprintf_mingw32kludge
 int snprintf_mingw32kludge(char *str, size_t size, const  char  *format, ...);
+int vsnprintf_mingw32kludge(char *str, size_t size, const  char  *format, va_list ap);
 
 /* mingw32 has no index() in string.h */
 extern char *index(const char *s, int c);
